<?php

namespace Webkul\SalesforceConnector\Controller\Adminhtml\Orders;

use Magento\Sales\Model\Order;

/**
 * Class GetAllExportIds
 */
class GetAllExportIds extends \Magento\Backend\App\Action
{
    protected $_resultPageFactory = false;
    protected $_json;
    protected $_orderModel;
    protected $_salesOrder;

    public function __construct(
        \Magento\Backend\App\Action\Context $context,
        \Magento\Framework\Json\Helper\Data $jsonHelper,
        \Webkul\SalesforceConnector\Model\OrderFactory $order,
        \Magento\Sales\Model\OrderFactory $salesOrder,
        \Magento\Framework\View\Result\PageFactory $resultPageFactory
    ) {

        $this->_resultPageFactory = $resultPageFactory;
        $this->_json = $jsonHelper;
        $this->_orderModel = $order;
        $this->_salesOrder = $salesOrder;
        parent::__construct($context);
    }

    public function execute()
    {
        $mapProducts = $exportIds = [];
        $exportData = [];
        if (\Webkul\SalesforceConnector\Helper\Connection::checkConnectionStatus()) {
            $orderModel = $this->_orderModel->create();
            $salesOrderModel = $this->_salesOrder->create();

            $orderCollection = $orderModel->getCollection()
                ->addFieldToSelect('magento_id')
                ->addFieldToFilter('sync_status', '1')
                ->getData();
            $mapProducts = array_column($orderCollection, 'magento_id');
            /** @var \Magento\Sales\Model\ResourceModel\Order\Collection $collection */
            $collection = $salesOrderModel->getCollection();
            $collection->addFieldToSelect(
                ['entity_id', 'increment_id', 'customer_email']
            );
            if ($mapProducts) {
                $collection->addFieldToFilter(
                    'entity_id',
                    ['nin' => $mapProducts]
                );
            }
            
            /** @var Order $order */
            foreach ($collection->getItems() as $order) {
                $exportData[] = [
                    'id' => $order->getId(),
                    'sku' => $order->getIncrementId(),
                    'name' => $order->getIncrementId() . ' by ' . $order->getCustomerEmail()
                ];
            }
        } else {
            $this->messageManager->addError(__("Check Connection"));
        }

        $this->getResponse()->setHeader('Content-type', 'application/json');
        $this->getResponse()->setBody($this->_json->jsonEncode($exportData));
    }
}
